[libgweather/wip/hadess/met-no-migration: 1/7] metno: Rename yr.no backend to met.no




commit 3f8f622e9a7d532b9041133bfcc42b67f0cdd9da
Author: Bastien Nocera <hadess hadess net>
Date:   Thu Jan 7 11:15:04 2021 +0100

    metno: Rename yr.no backend to met.no
    
    "The Yr API is now officially discontinued, and the Yr is now
    trademarked for the website and mobile apps only."
    
    Closes: #64

 libgweather/gweather-private.h                  |  2 +-
 libgweather/gweather-weather.c                  |  6 +++---
 libgweather/gweather-weather.h                  |  4 ++--
 libgweather/meson.build                         |  2 +-
 libgweather/test_libgweather.c                  |  2 +-
 libgweather/test_weather.c                      |  6 +++---
 libgweather/{weather-yrno.c => weather-metno.c} | 28 ++++++++++++-------------
 po-locations/POTFILES.skip                      |  2 +-
 po/POTFILES.in                                  |  2 +-
 po/as.po                                        | 16 +++++++-------
 po/bg.po                                        | 12 +++++------
 po/bn_IN.po                                     | 18 ++++++++--------
 po/bs.po                                        |  4 ++--
 po/crh.po                                       |  4 ++--
 po/et.po                                        |  4 ++--
 po/hi.po                                        | 16 +++++++-------
 po/kn.po                                        | 20 +++++++++---------
 po/mr.po                                        | 22 +++++++++----------
 po/or.po                                        | 20 +++++++++---------
 po/pa.po                                        | 20 +++++++++---------
 po/sl.po                                        |  4 ++--
 po/ta.po                                        | 24 ++++++++++-----------
 po/te.po                                        | 22 +++++++++----------
 po/ug.po                                        | 10 ++++-----
 po/vi.po                                        | 10 ++++-----
 25 files changed, 140 insertions(+), 140 deletions(-)
---
diff --git a/libgweather/gweather-private.h b/libgweather/gweather-private.h
index 0c740e92..cdb586b6 100644
--- a/libgweather/gweather-private.h
+++ b/libgweather/gweather-private.h
@@ -206,7 +206,7 @@ struct _GWeatherInfoPrivate {
 
 void           metar_start_open        (GWeatherInfo *info);
 gboolean       iwin_start_open         (GWeatherInfo *info);
-gboolean        yrno_start_open         (GWeatherInfo *info);
+gboolean        metno_start_open         (GWeatherInfo *info);
 gboolean        owm_start_open          (GWeatherInfo *info);
 
 gboolean       metar_parse             (gchar *metar,
diff --git a/libgweather/meson.build b/libgweather/meson.build
index e84ae249..c6c6f658 100644
--- a/libgweather/meson.build
+++ b/libgweather/meson.build
@@ -45,7 +45,7 @@ gweather_c_sources = [
   'gweather-weather.c',
   'weather-metar.c',
   'weather-iwin.c',
-  'weather-yrno.c',
+  'weather-metno.c',
   'weather-owm.c',
   'weather-sun.c',
   'weather-moon.c',
diff --git a/libgweather/test_libgweather.c b/libgweather/test_libgweather.c
index 84841517..3d9ad67d 100644
--- a/libgweather/test_libgweather.c
+++ b/libgweather/test_libgweather.c
@@ -782,7 +782,7 @@ test_weather_loop_use_after_free (void)
                                         GWEATHER_PROVIDER_METAR |
                                         GWEATHER_PROVIDER_IWIN |
                                         GWEATHER_PROVIDER_YAHOO |
-                                        GWEATHER_PROVIDER_YR_NO |
+                                        GWEATHER_PROVIDER_MET_NO |
                                         GWEATHER_PROVIDER_OWM);
     gweather_info_set_location (info, loc);
     g_signal_connect (G_OBJECT (info), "updated",
diff --git a/libgweather/test_weather.c b/libgweather/test_weather.c
index 832dee05..ffe7c92e 100644
--- a/libgweather/test_weather.c
+++ b/libgweather/test_weather.c
@@ -6,7 +6,7 @@
 
 static char *search_str;
 // gnome-weather uses:
-static GWeatherProvider providers = GWEATHER_PROVIDER_METAR | GWEATHER_PROVIDER_YR_NO | 
GWEATHER_PROVIDER_OWM;
+static GWeatherProvider providers = GWEATHER_PROVIDER_METAR | GWEATHER_PROVIDER_MET_NO | 
GWEATHER_PROVIDER_OWM;
 
 // default:
 //static GWeatherProvider providers = GWEATHER_PROVIDER_METAR | GWEATHER_PROVIDER_IWIN;
@@ -115,8 +115,8 @@ set_providers (GWeatherInfo *info)
         ADD_PROVIDER_STR("IWIN");
     if (providers & GWEATHER_PROVIDER_YAHOO)
         ADD_PROVIDER_STR("YAHOO");
-    if (providers & GWEATHER_PROVIDER_YR_NO)
-        ADD_PROVIDER_STR("YR_NO");
+    if (providers & GWEATHER_PROVIDER_MET_NO)
+        ADD_PROVIDER_STR("MET_NO");
     if (providers & GWEATHER_PROVIDER_OWM)
         ADD_PROVIDER_STR("OWM");
     if (providers == GWEATHER_PROVIDER_NONE) {
diff --git a/po-locations/POTFILES.skip b/po-locations/POTFILES.skip
index f9307de2..2654d674 100644
--- a/po-locations/POTFILES.skip
+++ b/po-locations/POTFILES.skip
@@ -9,5 +9,5 @@ libgweather/gweather-weather.c
 libgweather/weather-iwin.c
 libgweather/weather-metar.c
 libgweather/weather-owm.c
-libgweather/weather-yrno.c
+libgweather/weather-metno.c
 schemas/org.gnome.GWeather.gschema.xml
diff --git a/po/POTFILES.in b/po/POTFILES.in
index 1aacd691..69449757 100644
--- a/po/POTFILES.in
+++ b/po/POTFILES.in
@@ -10,5 +10,5 @@ libgweather/gweather-weather.c
 libgweather/weather-iwin.c
 libgweather/weather-metar.c
 libgweather/weather-owm.c
-libgweather/weather-yrno.c
+libgweather/weather-metno.c
 schemas/org.gnome.GWeather.gschema.xml
diff --git a/po/as.po b/po/as.po
index a0750e59..531eb177 100644
--- a/po/as.po
+++ b/po/as.po
@@ -105,7 +105,7 @@ msgstr "পশ্চিম"
 
 #: ../libgweather/weather.c:118
 msgid "West - Northwest"
-msgstr "পশ্চিম - উত্তৰপশ্চিম"
+msgstr "পশ্চিম - উততৰপশ্চিম"
 
 #: ../libgweather/weather.c:118
 msgid "Northwest"
@@ -181,7 +181,7 @@ msgstr "বৰষুণ"
 
 #: ../libgweather/weather.c:176
 msgid "Light rain"
-msgstr "পাতল বৰষুণ"
+msgstr "পাতল বৰুণ"
 
 #: ../libgweather/weather.c:176
 msgid "Moderate rain"
@@ -308,7 +308,7 @@ msgstr "সৰু শিলাৰ বৃষ্টি"
 #. PRECIPITATION
 #: ../libgweather/weather.c:183
 msgid "Unknown precipitation"
-msgstr "অজ্ঞাত বৃষ্টিপাত"
+msgstr "অজঞাত বৃষ্টিপাত"
 
 #. MIST
 #: ../libgweather/weather.c:184
@@ -661,10 +661,10 @@ msgstr ""
 #| "Weather data from the <a href=\"%s\">Norwegian Meteorological Institute</"
 #| "a>"
 msgid ""
-"Weather data from the <a href=\"http://yr.no/\";>Norwegian Meteorological "
+"Weather data from the <a href=\"https://www.met.no/\";>Norwegian Meteorological "
 "Institute</a>"
 msgstr ""
-"<a href=\"http://yr.no/\";>নৱৰৱীয়্যান্ বতৰ বিজ্ঞান প্ৰতিষ্ঠান</a> ৰ পৰা বতৰ "
+"<a href=\"https://www.met.no/\";>নৱৰৱীয়্যান্ বতৰ বিজ্ঞান প্ৰতিষ্ঠান</a> ৰ পৰা বতৰ "
 "তথ্য"
 
 #: ../schemas/org.gnome.GWeather.gschema.xml.h:1
@@ -717,7 +717,7 @@ msgid ""
 "Valid values are 'ms' (meters per second), 'kph' (kilometers per hour), "
 "'mph' (miles per hour), 'knots' and 'bft' (Beaufort scale)."
 msgstr ""
-"বতৰ দেখুৱাবলৈ ব্যৱহাৰ কৰা গতিৰ একক (উদাহৰণস্বৰূপ বায়ুৰ গতিৰ বাবে)। বৈধ "
+"বতৰ দেখুৱাবলৈ ব্যৱহাৰ কৰা গতি একক (উদাহৰণস্বৰূপ বায়ুৰ গতিৰ বাবে)। বৈধ "
 "মানসমূহ হল "
 "'ms' (মিটাৰ প্ৰতি ছেকেণ্ড), 'kph' (কিলোমিটাৰ প্ৰতি ঘন্টা), 'mph' (মাইল প্ৰতি "
 "ঘন্টা), 'knots' আৰু 'bft' (Beaufort স্কেইল)।"
@@ -733,7 +733,7 @@ msgid ""
 "equivalent to 1 hPa but shown differently), 'mm-hg' (millimeters of "
 "mercury), 'inch-hg' (inches of mercury), 'atm' (atmospheres)."
 msgstr ""
-"বতৰ দেখুৱাবলৈ ব্যৱহাৰ কৰা চাপৰ একক। বৈধ মানসমূহ হল 'kpa' (কিলোপাস্কেল), "
+"বতৰ দেখুৱাবলৈ ব্যৱহাৰ কৰা চাপৰ একক। বৈধ মানসমূহ হল 'kpa' (কিলোপাস্কে), "
 "'hpa' (হেক্টোপাস্কেল), 'mb' (মিলিবাৰ, গাণিতিকভাৱে 1 hPa ৰ সমতূল্য কিন্তু "
 "পৃথকভাৱে "
 "দেখুৱা হয়), 'mm-hg' (মাৰকিউৰিৰ মিলিমিটাৰ), 'inch-hg' (মাৰকিউৰিৰ ইঞ্চি), "
@@ -925,7 +925,7 @@ msgstr ""
 #~ msgstr "ৰেডাৰ মেপ প্ৰদৰ্শন কৰক"
 
 #~ msgid "Fetch a radar map on each update."
-#~ msgstr "প্ৰত্যেক উন্নয়নত এটা ৰেডাৰ মেপ পাব।"
+#~ msgstr "প্ৰত্যেক উন্নয়নত এটা ৰডাৰ মেপ পাব।"
 
 #~ msgid "Weather location information"
 #~ msgstr "অৱস্থানৰ বতৰ সংক্ৰান্ত তথ্য"
diff --git a/po/bg.po b/po/bg.po
index cf2f602a..7890a281 100644
--- a/po/bg.po
+++ b/po/bg.po
@@ -114,7 +114,7 @@ msgstr "Северозапад"
 
 #: ../libgweather/weather.c:118
 msgid "North - Northwest"
-msgstr "Север — северозапад"
+msgstr "Север — севрозапад"
 
 #: ../libgweather/weather.c:125
 msgctxt "wind direction"
@@ -534,7 +534,7 @@ msgstr "%.1f mile/h"
 #: ../libgweather/weather.c:964
 #, c-format
 msgid "%.1f km/h"
-msgstr "%.1f km/h"
+msgstr "%.1fkm/h"
 
 #. TRANSLATOR: This is the wind speed in meters per second
 #: ../libgweather/weather.c:967
@@ -658,10 +658,10 @@ msgstr ""
 #.
 #: ../libgweather/weather-yrno.c:509
 msgid ""
-"Weather data from the <a href=\"http://yr.no/\";>Norwegian Meteorological "
+"Weather data from the <a href=\"https://www.met.no/\";>Norwegian Meteorological "
 "Institute</a>"
 msgstr ""
-"Данните са от <a href=\"http://yr.no/\";>Норвежкия метеорологичен институт</a>"
+"Данните са от <a href=\"https://www.met.no/\";>Норвежкия метеорологичен институт</a>"
 
 #: ../schemas/org.gnome.GWeather.gschema.xml.h:1
 msgid "URL for the radar map"
@@ -684,7 +684,7 @@ msgid ""
 "The unit of temperature used for showing weather. Valid values are 'kelvin', "
 "'centigrade' and 'fahrenheit'."
 msgstr ""
-"Мерна единица за температурата. Стойността е  „kelvin“ (келвин), "
+"Мерна единица за тмпературата. Стойността е  „kelvin“ (келвин), "
 "„centigrade“ (градус по Целзий) или „fahrenheit“ (градус по Фаренхайт)"
 
 #: ../schemas/org.gnome.GWeather.gschema.xml.h:5
@@ -726,7 +726,7 @@ msgid ""
 "mercury), 'inch-hg' (inches of mercury), 'atm' (atmospheres)."
 msgstr ""
 "Мерна единица за налягане. Стойността е „kpa“ (килопаскал), "
-"„hpa“ (хектопаскал), „mb“ (милибар, равен е на хектопаскал), „mm-"
+"„hpa“ (хектопаскал), „mb“ (милибар, равен е на хектопаска), „mm-"
 "hg“ (милиметър живачен стълб), „inch-hg“ (инч живачен стълб) или "
 "„atm“ (атмосфера).\""
 
diff --git a/po/bn_IN.po b/po/bn_IN.po
index 943037bb..7a2c5ee8 100644
--- a/po/bn_IN.po
+++ b/po/bn_IN.po
@@ -305,7 +305,7 @@ msgstr "শিলাবৃষ্টি"
 
 #: ../libgweather/weather.c:181
 msgid "Hail showers"
-msgstr "শিলাবৃষ্টি"
+msgstr "শিলাৃষ্টি"
 
 #. SMALL_HAIL
 #: ../libgweather/weather.c:182
@@ -684,10 +684,10 @@ msgstr ""
 #.
 #: ../libgweather/weather-yrno.c:484
 msgid ""
-"Weather data from the <a href=\"http://yr.no/\";>Norwegian Meteorological "
+"Weather data from the <a href=\"https://www.met.no/\";>Norwegian Meteorological "
 "Institute</a>"
 msgstr ""
-"<a href=\"http://yr.no/\";>নরওয়েজিয়ান মিটিওরোলজিক্যাল ইনস্টিটিউট</a> থেকে "
+"<a href=\"https://www.met.no/\";>নরওয়েজিয়ান মিটিওরোলজিক্যাল ইনস্টিটিউট</a> থেকে "
 "অাবহাওয়া সংক্রান্ত ডেটা"
 
 #: ../schemas/org.gnome.GWeather.gschema.xml.h:1
@@ -701,7 +701,7 @@ msgid ""
 msgstr ""
 "রেডার ম্যাপ প্রাপ্তির উদ্দেশ্যে ব্যবহৃত স্বনির্ধারিত URL, অথবা রেডার ম্যাপ "
 "নিষ্ক্রিয় "
-"করার জন্য ফাঁকা মান"
+"কার জন্য ফাঁকা মান"
 
 #: ../schemas/org.gnome.GWeather.gschema.xml.h:3
 msgid "Temperature unit"
@@ -726,7 +726,7 @@ msgid ""
 "for distance of important events). Valid values are 'meters', 'km' and "
 "'miles'."
 msgstr ""
-"আবহাওয়ার তথ্য প্রদর্শনকালে ব্যবহারযোগ্য দুরত্বের একক (যেমন দৃশ্যমান দুরত্ব "
+"আবহাওয়ার তথ্য প্রদর্নকালে ব্যবহারযোগ্য দুরত্বের একক (যেমন দৃশ্যমান দুরত্ব "
 "অথবা গুরুত্বপূর্ণ "
 "ঘটনা থেকে দুরত্ব)। বৈধ মানগুলি হল 'meters', 'km' ও 'miles'."
 
@@ -742,7 +742,7 @@ msgid ""
 msgstr ""
 "আবহাওয়ার তথ্য প্রদর্শনকালে ব্যবহারযোগ্য গতির একক (যেমন হাওয়ার গতি)। বৈধ "
 "মানগুলি হল "
-"'ms' (মিটার প্রতি সেকেন্ড), 'kph' (কিলোমিটার প্রতি ঘন্টা), 'mph' (মাইল প্রতি "
+"'ms' (মিটার প্রতি সেকেন্ড), 'kph' (কিলোমিটর প্রতি ঘন্টা), 'mph' (মাইল প্রতি "
 "ঘন্টা), 'knots' ও 'bft' (বিউফোর্ট স্কেল)।"
 
 #: ../schemas/org.gnome.GWeather.gschema.xml.h:9
@@ -758,7 +758,7 @@ msgid ""
 msgstr ""
 "আবহাওয়ার তথ্য প্রদর্শনকালে ব্যবহারযোগ্য বায়ু চাপের একক।  বৈধ মানগুলি হল "
 "'kpa' (kilopascal), 'hpa' (hectopascal), 'mb' (millibar, গাণিতিক মাপে1 hPa-র "
-"সমতূল্য কিন্তু ভিন্ন রূপে প্রদর্শিত), 'mm-hg' (millimeters of mercury), 'inch-"
+"সমতূল্য কিন্তু ভিন্ন রূপে প্রদর্শি), 'mm-hg' (millimeters of mercury), 'inch-"
 "hg' (inches of mercury), 'atm' (atmospheres)।"
 
 #: ../schemas/org.gnome.GWeather.gschema.xml.h:11
@@ -785,7 +785,7 @@ msgstr ""
 "ডাটাবেস "
 "থেকে সংগ্রহ করা মান উপেক্ষার করার উদ্দেশ্যে তৃতীয় ক্ষেত্রে (অক্ষাংশ, "
 "দ্রাঘিমাংশ) লেখা "
-"হয়। এটি শুধুমাত্র সূর্যোদয় ও চাঁদের কলার গণনা করতে ব্যবহৃত হয়, এবং আবহাওয়ার "
+"হয়। এটি শুধুমাত্র সূর্যোদয় ও চাঁদের কলার গণনা করতে ব্বহৃত হয়, এবং আবহাওয়ার "
 "পূর্বাভাসে "
 "প্রয়োগ হয় না।"
 
@@ -992,7 +992,7 @@ msgstr ""
 #~ msgstr "স্বয়ংক্রিয়রূপে তথ্য আপডেট করা হবে"
 
 #~ msgid "Use custom url for the radar map"
-#~ msgstr "রেডার ম্যাপের জন্য স্বনির্বাচিত url ব্যবহৃত হবে"
+#~ msgstr "রেডার ম্যাপের জন্য স্বনিরবাচিত url ব্যবহৃত হবে"
 
 #~ msgid "Use metric units"
 #~ msgstr "মেট্রিক একক ব্যবহৃত হবে"
diff --git a/po/bs.po b/po/bs.po
index e3ebb6da..18e85688 100644
--- a/po/bs.po
+++ b/po/bs.po
@@ -649,10 +649,10 @@ msgstr ""
 #.
 #: ../libgweather/weather-yrno.c:509
 msgid ""
-"Weather data from the <a href=\"http://yr.no/\";>Norwegian Meteorological "
+"Weather data from the <a href=\"https://www.met.no/\";>Norwegian Meteorological "
 "Institute</a>"
 msgstr ""
-"Vremenski podaci s <a href=\"http://yr.no/\";>Norveški meteorološki institut</"
+"Vremenski podaci s <a href=\"https://www.met.no/\";>Norveški meteorološki institut</"
 "a>"
 
 #: ../schemas/org.gnome.GWeather.gschema.xml.h:1
diff --git a/po/crh.po b/po/crh.po
index 151c0d0e..5ca620f0 100644
--- a/po/crh.po
+++ b/po/crh.po
@@ -733,10 +733,10 @@ msgstr "METAR verileri alınamadı: %d %s.\n"
 #.
 #: ../libgweather/weather-yrno.c:416
 msgid ""
-"Weather data from the <a href=\"http://yr.no/\";>Norwegian Meteorological "
+"Weather data from the <a href=\"https://www.met.no/\";>Norwegian Meteorological "
 "Institute</a>"
 msgstr ""
-"<a href=\"http://yr.no/\";>Norveç Meteorologik İnstitut</a>'tan hava verileri"
+"<a href=\"https://www.met.no/\";>Norveç Meteorologik İnstitut</a>'tan hava verileri"
 
 # tüklü
 #: ../schemas/org.gnome.GWeather.gschema.xml.h:1
diff --git a/po/et.po b/po/et.po
index 7d8076fb..4052eb83 100644
--- a/po/et.po
+++ b/po/et.po
@@ -518,10 +518,10 @@ msgstr "METAR-andmeid pole võimalik hankida: %d %s.\n"
 #. That's very nice of them!
 #.
 msgid ""
-"Weather data from the <a href=\"http://yr.no/\";>Norwegian Meteorological "
+"Weather data from the <a href=\"https://www.met.no/\";>Norwegian Meteorological "
 "Institute</a>"
 msgstr ""
-"Ilmaandmed <a href=\"http://yr.no/\";>Norra Meteoroloogia Instituudist</a>"
+"Ilmaandmed <a href=\"https://www.met.no/\";>Norra Meteoroloogia Instituudist</a>"
 
 msgid "URL for the radar map"
 msgstr "Radarikaardi URL"
diff --git a/po/hi.po b/po/hi.po
index daeba2e6..59e8ddc1 100644
--- a/po/hi.po
+++ b/po/hi.po
@@ -286,7 +286,7 @@ msgstr "लघु तुषार-वर्षा"
 #: ../libgweather/weather.c:180
 #| msgid "Moderate snow"
 msgid "Moderate sleet"
-msgstr "साधारण तुषार-वर्षा"
+msgstr "साधारण तुषार-व्षा"
 
 #: ../libgweather/weather.c:180
 #| msgid "Heavy snow"
@@ -327,7 +327,7 @@ msgstr "छोटे ओलों का तूफान"
 
 #: ../libgweather/weather.c:182
 msgid "Showers of small hail"
-msgstr "छोटे ओलों के बौछार"
+msgstr "छोटे ओलों के बौछा"
 
 #. PRECIPITATION
 #: ../libgweather/weather.c:183
@@ -422,7 +422,7 @@ msgstr "रेत का तूफान"
 
 #: ../libgweather/weather.c:193
 msgid "Sandstorm in the vicinity"
-msgstr "आस पास के क्षेत्रों में रेत का तूफान"
+msgstr "आस पास के क्षेत्रों में रत का तूफान"
 
 #: ../libgweather/weather.c:193
 msgid "Heavy sandstorm"
@@ -458,7 +458,7 @@ msgstr "धूल युक्त चक्रवात"
 
 #: ../libgweather/weather.c:197
 msgid "Dust whirls in the vicinity"
-msgstr "आस पास के क्षेत्रों में धूल युक्त चक्रवात"
+msgstr "आस पास के क्षेत्रों में धूल युक् चक्रवात"
 
 #: ../libgweather/weather.c:706
 #| msgid "%a, %b %d / %H:%M"
@@ -690,10 +690,10 @@ msgstr ""
 #.
 #: ../libgweather/weather-yrno.c:484
 msgid ""
-"Weather data from the <a href=\"http://yr.no/\";>Norwegian Meteorological "
+"Weather data from the <a href=\"https://www.met.no/\";>Norwegian Meteorological "
 "Institute</a>"
 msgstr ""
-"<a href=\"http://yr.no/\";>Norwegian Meteorological Institute</a> से मौसम के "
+"<a href=\"https://www.met.no/\";>Norwegian Meteorological Institute</a> से मौसम के "
 "आँकड़े"
 
 #: ../schemas/org.gnome.GWeather.gschema.xml.h:1
@@ -762,7 +762,7 @@ msgid ""
 "equivalent to 1 hPa but shown differently), 'mm-hg' (millimeters of "
 "mercury), 'inch-hg' (inches of mercury), 'atm' (atmospheres)."
 msgstr ""
-"मौसम दिखाने के लिए इस्तेमाल किया जाने वाला दबाव की इकाई. मान्य मान  "
+"मौसम दिखाने के लए इस्तेमाल किया जाने वाला दबाव की इकाई. मान्य मान  "
 "'केपीए' (kilopascal), 'hPa' (hectopascal), 'एमबी' (millibar, गणितीय 1 hPa के "
 "बराबर है, लेकिन अलग ढंग से दिखाया गया है), 'mm-hg (पारा के millimeters), "
 "'inch-"
@@ -789,7 +789,7 @@ msgstr ""
 "है. यह खाली नहीं हो सकता है और Locations.xml फ़ाइल में &lt;code&gt; टैग के "
 "अनुरूप होना "
 "चाहिए चाहिए. तीसरा क्षेत्र के एक टपल का (अक्षांश, देशांतर) हैं,  डेटाबेस से "
-"लिया मान को "
+"लया मान को "
 "पार करेगा. यह केवल सूर्योदय और चाँद चरण की गणना के लिए प्रयोग किया जाता है, "
 "मौसम की "
 "भविष्यवाणी के लिए नहीं."
diff --git a/po/kn.po b/po/kn.po
index d0f02473..9c621aaf 100644
--- a/po/kn.po
+++ b/po/kn.po
@@ -183,7 +183,7 @@ msgstr "ಸಣ್ಣ ಮಳೆ"
 
 #: ../libgweather/weather.c:176
 msgid "Moderate rain"
-msgstr "ಸಾಧಾರಣ ಮಳೆ"
+msgstr "ಸಧಾರಣ ಮಳೆ"
 
 #: ../libgweather/weather.c:176
 msgid "Heavy rain"
@@ -305,7 +305,7 @@ msgstr "ಸಣ್ಣದಾದ ಆಲಿಕಲ್ಲಿನಿಂದ ಕೂಡಿ
 
 #: ../libgweather/weather.c:182
 msgid "Showers of small hail"
-msgstr "ಸಣ್ಣದಾದ ಆಲಿಕಲ್ಲಿನಿಂದ ಕೂಡಿದ ಸಿಂಚನ"
+msgstr "ಸಣ್ದಾದ ಆಲಿಕಲ್ಲಿನಿಂದ ಕೂಡಿದ ಸಿಂಚನ"
 
 #. PRECIPITATION
 #: ../libgweather/weather.c:183
@@ -432,7 +432,7 @@ msgstr "ಸುಂಟರ ಗಾಳಿ"
 #. DUST_WHIRLS
 #: ../libgweather/weather.c:197
 msgid "Dust whirls"
-msgstr "ರಭಸದಿಂದ ತಿರುಗುವ ಧೂಳು"
+msgstr "ರಭಸದಿಂದ ತಿರುುವ ಧೂಳು"
 
 #: ../libgweather/weather.c:197
 msgid "Dust whirls in the vicinity"
@@ -645,13 +645,13 @@ msgstr "METAR ಮಾಹಿತಿಯನ್ನು ಪಡೆಯುವಲ್ಲಿ 
 
 #: ../libgweather/weather-owm.c:385
 #| msgid ""
-#| "Weather data from the <a href=\"http://yr.no/\";>Norwegian Meteorological "
+#| "Weather data from the <a href=\"https://www.met.no/\";>Norwegian Meteorological "
 #| "Institute</a>"
 msgid ""
 "Weather data from the <a href=\"http://openweathermap.org\";>Open Weather Map "
 "project</a>"
 msgstr ""
-"<a href=\"http://yr.no/\";>ಓಪನ್ ವೆದರ್ ಮ್ಯಾಪ್ ಯೋಜನೆ</a>ಯಿಂದ ಹವಾಮಾನ "
+"<a href=\"https://www.met.no/\";>ಓಪನ್ ವೆದರ್ ಮ್ಯಾಪ್ ಯೋಜನೆ</a>ಯಿಂದ ಹವಾಮಾನ "
 "ಮಾಹಿತಿ"
 
 #. The new (documented but not advertised) API is less strict in the
@@ -662,10 +662,10 @@ msgstr ""
 #.
 #: ../libgweather/weather-yrno.c:484
 msgid ""
-"Weather data from the <a href=\"http://yr.no/\";>Norwegian Meteorological "
+"Weather data from the <a href=\"https://www.met.no/\";>Norwegian Meteorological "
 "Institute</a>"
 msgstr ""
-"<a href=\"http://yr.no/\";>ನಾರ್ವೇಜಿಯನ್ ಮೆಟೆರೊಲಾಜಿಕಲ್ ಇನ್‌ಸ್ಟಿಟ್ಯೂಟ್‌</a>ನಿಂದ "
+"<a href=\"https://www.met.no/\";>ನಾರ್ವೇಜಿಯನ್ ಮಟೆರೊಲಾಜಿಕಲ್ ಇನ್‌ಸ್ಟಿಟ್ಯೂಟ್‌</a>ನಿಂದ "
 "ಹವಾಮಾನ "
 "ಮಾಹಿತಿ"
 
@@ -705,7 +705,7 @@ msgid ""
 "'miles'."
 msgstr ""
 "ಹವಮಾನವನ್ನು ತೋರಿಸಲು ಬಳಸಲಾಗುವ ದೂರದ ಏಕಮಾನ (ಉದಾಹರಣೆಗೆ ಗೋಚರಿಕೆ ಅಥವ ಪ್ರಮುಖ ಘಟನೆಗಳ "
-"ನಡುವಿನ ದೂರಕ್ಕಾಗಿ). ಮಾನ್ಯವಾದ ಮೌಲ್ಯಗಳೆಂದರೆ 'ಮೀಟರುಗಳು', 'ಕಿಮೀ' ಮತ್ತು 'ಮೈಲುಗಳು'."
+"ನಡುವಿನ ದೂರಕ್ಕಾಗಿ). ಮಾನ್ಯವಾದ ಮೌಲ್ಯಗಳೆಂದರೆ 'ೀಟರುಗಳು', 'ಕಿಮೀ' ಮತ್ತು 'ಮೈಲುಗಳು'."
 
 #: ../schemas/org.gnome.GWeather.gschema.xml.h:7
 msgid "Speed unit"
@@ -736,7 +736,7 @@ msgstr ""
 "ಹವಮಾನವನ್ನು ತೋರಿಸಲು ಬಳಸಲಾಗುವ ಒತ್ತಡದ ವೇಗ. ಮಾನ್ಯವಾದ ಮೌಲ್ಯಗಳೆಂದರೆ 'kpa' "
 "(ಕಿಲೋಪ್ಯಾಸ್ಕಲ್), "
 "'hpa' (ಹೆಕ್ಟೋಪ್ಯಾಸ್ಕಲ್), 'mb' (ಮಿಲಿಬಾರ್, ಗಣತೀಯದ ಲೆಕ್ಕಾಚಾರದ ಪ್ರಕಾರ 1 hPa ಗೆ "
-"ಸಮನಾಗಿರುತ್ತದೆ ಆದರೆ ಭಿನ್ನವಾಗಿ ತೋರಿಸಲಾಗುತ್ತದೆ), 'mm-hg' (ಮರ್ಕ್ಯುರಿಯ ಮಿಲಿಮೀಟರ್), "
+"ಸಮನಾಗಿರುತ್ತದೆ ಆದರೆ ಭಿನ್ನವಾಗಿ ತೋರಿಸಲಾಗುತ್ತದೆ), 'mm-hg' (ಮರ್ಕ್ಯುರಿಯ ಮಿಿಮೀಟರ್), "
 "'inch-hg' (ಮರ್ಕ್ಯುರಿಯ ಇಂಚು), 'atm' (ಅಟ್ಮಾಸ್ಫಿಯರುಗಳು)."
 
 #: ../schemas/org.gnome.GWeather.gschema.xml.h:11
@@ -753,7 +753,7 @@ msgid ""
 "value taken from the database. This is only used for sunrise and moon phase "
 "calculations, not for weather forecast."
 msgstr ""
-"ಹವಾಮಾನ ಕಿರುಅನ್ವಯವು ಇರುವ ಸ್ಥಳದ ಪೂರ್ವನಿಯೋಜಿತ ಸ್ಥಳ. ಹೆಸರಿನಲ್ಲಿನ ಮೊದಲ ಭಾಗವನ್ನು "
+"ಹವಾಮಾನ ಕಿರುಅನ್ವಯವು ಇರುವ ಸ್ಥಳದ ಪೂರ್ವನಿಯೋಜಿತ ಸ್ಥಳ. ಹೆಸರಿನಲ್ಲಿನ ೊದಲ ಭಾಗವನ್ನು "
 "ತೋರಿಸಲಾಗುತ್ತದೆ. ಖಾಲಿ ಇದ್ದಲ್ಲಿ, ಇದನ್ನು ಸ್ಥಳಗಳ ದತ್ತಸಂಚಯದಿಂದ "
 "ತೆಗೆದುಕೊಳ್ಳಲಾಗುತ್ತದೆ. "
 "METAR ಸಂಕೇತದಲ್ಲಿನ ಎರಡನೆಯ ಭಾಗವು ಪೂರ್ವನಿಯೋಜಿತ ಹವಾಮಾನ ಕೇಂದ್ರವಾಗಿರುತ್ತದೆ. ಇದು "
diff --git a/po/mr.po b/po/mr.po
index 801e12f3..b9798a5d 100644
--- a/po/mr.po
+++ b/po/mr.po
@@ -24,7 +24,7 @@ msgstr ""
 #: ../data/glade/libgweather.xml.in.h:1
 #| msgid "Location coordinates"
 msgid "Location Entry"
-msgstr "ठिकाणाची नोंदणी"
+msgstr "ठिकाणाी नोंदणी"
 
 #: ../data/glade/libgweather.xml.in.h:2
 msgid "Timezone Menu"
@@ -312,7 +312,7 @@ msgstr "छोट्या गारांच्या सरी"
 #. PRECIPITATION
 #: ../libgweather/weather.c:183
 msgid "Unknown precipitation"
-msgstr "अज्ञात वृष्टी"
+msgstr "अज्ञात वृष्ट"
 
 #. MIST
 #: ../libgweather/weather.c:184
@@ -648,13 +648,13 @@ msgstr "METAR माहिती प्राप्त करण्यास अ
 
 #: ../libgweather/weather-owm.c:385
 #| msgid ""
-#| "Weather data from the <a href=\"http://yr.no/\";>Norwegian Meteorological "
+#| "Weather data from the <a href=\"https://www.met.no/\";>Norwegian Meteorological "
 #| "Institute</a>"
 msgid ""
 "Weather data from the <a href=\"http://openweathermap.org\";>Open Weather Map "
 "project</a>"
 msgstr ""
-"<a href=\"http://openweathermap.org\";>ओपन वेदर मॅप प्रकल्प</a> पासूनचे हवामान "
+"<a href=\"http://openweathermap.org\";>ओपन वेदर मॅप प्रकल्प</a> पाूनचे हवामान "
 "डाटा"
 
 #. The new (documented but not advertised) API is less strict in the
@@ -665,10 +665,10 @@ msgstr ""
 #.
 #: ../libgweather/weather-yrno.c:484
 msgid ""
-"Weather data from the <a href=\"http://yr.no/\";>Norwegian Meteorological "
+"Weather data from the <a href=\"https://www.met.no/\";>Norwegian Meteorological "
 "Institute</a>"
 msgstr ""
-"<a href=\"http://yr.no/\";>नॉर्वेजिअन मिटिओरोलॉजिकल इंस्टिट्युट</a> पासूनचे "
+"<a href=\"https://www.met.no/\";>नॉर्वेजिअन मिटिओरोलॉजिकल इंस्टिट्युट</a> पासूनचे "
 "हवामान "
 "डाटा"
 
@@ -681,7 +681,7 @@ msgid ""
 "The custom URL from where to retrieve a radar map, or empty for disabling "
 "radar maps."
 msgstr ""
-"पसंतीचे URL जेथून रडार मॅप प्राप्त करायचे, किंवा रडार मॅप्स् बंद करण्यासाठी "
+"पसंतीचे URL जेथून रडार मॅप प्राप्त करायचे, िंवा रडार मॅप्स् बंद करण्यासाठी "
 "रिकामे करा."
 
 #: ../schemas/org.gnome.GWeather.gschema.xml.h:3
@@ -706,7 +706,7 @@ msgid ""
 "for distance of important events). Valid values are 'meters', 'km' and "
 "'miles'."
 msgstr ""
-"हवामान दाखवण्यासाठी वापरण्याजोगी अंतराचे युनिट (उदाहरणार्थ व्हिजिबिलिटिकरीता "
+"हवामान दाखण्यासाठी वापरण्याजोगी अंतराचे युनिट (उदाहरणार्थ व्हिजिबिलिटिकरीता "
 "किंवा "
 "महत्वाच्या घटनांकरीता अंतर). वैध मूल्ये 'मिटर्स्', 'km' व 'माइल्स्' आहे."
 
@@ -722,7 +722,7 @@ msgid ""
 msgstr ""
 "हवामान दाखवण्यासाठी वापरण्याजोगी वेगचे युनिट (उदाहरणार्थ हवेच्या वेगकरीता). "
 "वैध मूल्ये "
-"'ms' (मिटर्स् पर सेकंद), 'kph' (किलोमिटर्स् पर आव्हर), 'mph' (माइल्स् पर "
+"'ms' (मटर्स् पर सेकंद), 'kph' (किलोमिटर्स् पर आव्हर), 'mph' (माइल्स् पर "
 "आव्हर), "
 "'knots' व 'bft' (बिफोर्ट स्केल) असे आहे."
 
@@ -804,7 +804,7 @@ msgstr ""
 #~ msgstr "अपरिचीत"
 
 #~ msgid "'fahrenheit'"
-#~ msgstr "'फॅरेनहैट'"
+#~ msgstr "'फॅेनहैट'"
 
 #~ msgid "'miles'"
 #~ msgstr "'माइल्स्'"
@@ -950,7 +950,7 @@ msgstr ""
 #~ "Nearby major zone, such as a capital city, as found from http://git.gnome.";
 #~ "org/cgit/libgweather/plain/data/Locations.xml.in"
 #~ msgstr ""
-#~ "नजीकचे मूख्य झोन, जसे की राजधानी शहर, http://git.gnome.org/cgit/libgweather/";
+#~ "जीकचे मूख्य झोन, जसे की राजधानी शहर, http://git.gnome.org/cgit/libgweather/";
 #~ "plain/data/Locations.xml.in येथील प्रमाणे"
 
 #~ msgid "Not used anymore"
diff --git a/po/or.po b/po/or.po
index a44a1442..83223984 100644
--- a/po/or.po
+++ b/po/or.po
@@ -111,7 +111,7 @@ msgstr "ଅବୈଧ"
 
 #: ../libgweather/weather.c:146
 msgid "Clear Sky"
-msgstr "ପରିଷ୍କାର ଆକାଶ"
+msgstr "ପରିଷକାର ଆକାଶ"
 
 #: ../libgweather/weather.c:147
 msgid "Broken clouds"
@@ -146,7 +146,7 @@ msgstr "ବିଜୁଳି ଘଡଘଡି ସହିତ ବର୍ଷା"
 #. DRIZZLE
 #: ../libgweather/weather.c:190
 msgid "Drizzle"
-msgstr "ଝିପିଝିପି ବର୍ଷା"
+msgstr "ଝିପିଝିପି ବ୍ଷା"
 
 #: ../libgweather/weather.c:190
 msgid "Light drizzle"
@@ -662,9 +662,9 @@ msgstr "METAR ତଥ୍ଯ ହାସଲ କରିବାରେ ବିଫଳ: %d %
 #.
 #: ../libgweather/weather-yrno.c:416
 msgid ""
-"Weather data from the <a href=\"http://yr.no/\";>Norwegian Meteorological "
+"Weather data from the <a href=\"https://www.met.no/\";>Norwegian Meteorological "
 "Institute</a>"
-msgstr "<a href=\"http://yr.no/\";>ନରୱେ  ବାୟୁମଣ୍ଡଳୀୟ ସଂସ୍ଥା</a> ରୁ ଜଳବାୟୁ ତଥ୍ୟ"
+msgstr "<a href=\"https://www.met.no/\";>ନରୱେ  ବାୟୁମଣ୍ଡଳୀୟ ସଂସ୍ଥା</a> ରୁ ଜଳବାୟୁ ତଥ୍ୟ"
 
 #: ../schemas/org.gnome.GWeather.gschema.xml.h:1
 msgid "URL for the radar map"
@@ -675,7 +675,7 @@ msgid ""
 "The custom URL from where to retrieve a radar map, or empty for disabling "
 "radar maps."
 msgstr ""
-"ଇଚ୍ଛାରୂପଣ URL ଯେଉଁଠାରୁ ରଡାର ମାନଚିତ୍ରକୁ ପୁନଃପ୍ରାପ୍ତ କରାଯାଇଥାଏ, ଅଥବା ରାଡାର "
+"ଇଚ୍ଛାରୂପଣ URL ଯେଉଁଠାର ରଡାର ମାନଚିତ୍ରକୁ ପୁନଃପ୍ରାପ୍ତ କରାଯାଇଥାଏ, ଅଥବା ରାଡାର "
 "ମାନଚିତ୍ରକୁ ନିଷ୍କ୍ରିୟ "
 "କରିବା ପାଇଁ।"
 
@@ -738,7 +738,7 @@ msgstr ""
 "ମୂଲ୍ୟଗୁଡ଼ିକ ହେଉଛି 'ମି/"
 "ସେ' (ସେକଣ୍ଡ ପ୍ରତି ମିଟର), 'କିମି/ଘ' (ଘଣ୍ଟା ପ୍ରତି କିଲୋମିଟର), 'ମାଇଲ/ଘ' (ଘଣ୍ଟା "
 "ପ୍ରତି ମାଇଲ), "
-"'ନୋଟସ' ଏବଂ 'ବିଏଫଟି' (ବିୟୁଫୋର୍ଟ ମାପାଙ୍କ)।"
+"'ନୋଟସ' ଏବଂ 'ିଏଫଟି' (ବିୟୁଫୋର୍ଟ ମାପାଙ୍କ)।"
 
 #. TRANSLATORS: pick a default pressure unit for your locale, see key description
 #. for valid values
@@ -759,7 +759,7 @@ msgid ""
 msgstr ""
 "ଜଳବାୟୁ ଦର୍ଶାଇବା ପାଇଁ ବ୍ୟବହୃତ ଚାପର ଏକକ। ବୈଧ ମୂଲ୍ୟଗୁଡ଼ିକ ହେଉଛି'କେପିଏ' (କିଲୋ "
 "ପାସକାଲ), "
-"'ଏଚପିଏ' (ହେକ୍ଟୋ ପାସକାଲ), 'ଏମବି' (ମିଲିବାର, ଗାଣିତିକ ଭାବରେ 1 ଏଚପିଏ ସହିତ ସମାନ "
+"'ଏଚପିଏ' (ହେକ୍ଟୋ ପାସକାଲ), 'ଏମବି' (ମଲିବାର, ଗାଣିତିକ ଭାବରେ 1 ଏଚପିଏ ସହିତ ସମାନ "
 "କିନ୍ତୁ ଭିନ୍ନ "
 "ଭାବରେ ଦର୍ଶାଯାଇଥାଏ), 'ଏମଏମ-ଏଚଜି' (ପାରଦ ମିଲିମିଟର), 'ଇଞ୍ଚ-ଏଚଜି' (ପାରଦ ଇଞ୍ଚ), "
 "'ଏଟିଏମ' (ବାୟୁମଣ୍ଡଳ)।"
@@ -911,7 +911,7 @@ msgstr ""
 #~ "Latitude and longitude of your location expressed in DD-MM-SS[NS] DD-MM-SS"
 #~ "[EW]."
 #~ msgstr ""
-#~ "ଆପଣଙ୍କର ଅବସ୍ଥାର ଅକ୍ଷାଂଶ ଏବଂ ଦ୍ରାଘିମା DD-MM-SS[NS] DD-MM-SS[EW] ରେ ପ୍ରକାଶିତ "
+#~ "ଆପଣଙ୍କର ଅବସ୍ଥାର ଅକଷାଂଶ ଏବଂ ଦ୍ରାଘିମା DD-MM-SS[NS] DD-MM-SS[EW] ରେ ପ୍ରକାଶିତ "
 #~ "କରାୟାଏ।"
 
 #~ msgid "Location coordinates"
@@ -934,7 +934,7 @@ msgstr ""
 #~ msgstr "ରଡାର ଅବସ୍ଥାନ"
 
 #~ msgid "The city that gweather displays information for."
-#~ msgstr "ଯେଉଁ ମହାନଗର ପାଇଁ ଜି-ଓ୍ବେଦାର ସୂଚନା ପ୍ରଦର୍ଶିତ କରୁଅଛି।"
+#~ msgstr "ଯେଉଁ ମହାନଗର ପାଁ ଜି-ଓ୍ବେଦାର ସୂଚନା ପ୍ରଦର୍ଶିତ କରୁଅଛି।"
 
 #~ msgid "The interval, in seconds, between automatic updates."
 #~ msgstr "ସ୍ବୟଂଚାଳିତ ଅଦ୍ଯତନ ମାନଙ୍କ ମଧ୍ଯରେ ବିରତି ସମୟ, ସେକେଣ୍ଡରେ"
@@ -958,7 +958,7 @@ msgstr ""
 #~ msgstr "ତଥ୍ଯକୁ ସ୍ବଯଂଚାଳିତଭାବରେ ଅପଡେଟ କର"
 
 #~ msgid "Use custom url for the radar map"
-#~ msgstr "ରାଡାର ମାନଚିତ୍ର ପାଇଁ ଇଚ୍ଛାରୂପଣ ୟୁ.ଆର.ଏଲ. କୁ ବ୍ଯବହାର କରନ୍ତୁ"
+#~ msgstr "ରାଡାର ାନଚିତ୍ର ପାଇଁ ଇଚ୍ଛାରୂପଣ ୟୁ.ଆର.ଏଲ. କୁ ବ୍ଯବହାର କରନ୍ତୁ"
 
 #~ msgid "Use metric units"
 #~ msgstr "ମେଟ୍ରିକ ଯୁନିଟଗୁଡିକୁ ଉପୟୋଗକର"
diff --git a/po/pa.po b/po/pa.po
index 1154023c..aa41162a 100644
--- a/po/pa.po
+++ b/po/pa.po
@@ -266,7 +266,7 @@ msgstr "ਖਿਲਰੇ ਬੱਦਲ"
 
 #: ../libgweather/gweather-weather.c:167
 msgid "Few clouds"
-msgstr "ਹਲਕੇ ਬੱਦਲ"
+msgstr "ਹਕੇ ਬੱਦਲ"
 
 #: ../libgweather/gweather-weather.c:168
 msgid "Overcast"
@@ -302,7 +302,7 @@ msgstr "ਬੂੰਦਾਬਾਂਦੀ"
 #: ../libgweather/gweather-weather.c:219
 #| msgid "Light drizzle"
 msgid "light drizzle"
-msgstr "ਹਲਕੀ ਬੂੰਦਾਬਾਂਦੀ"
+msgstr "ਹਲਕੀ ਬੰਦਾਬਾਂਦੀ"
 
 #: ../libgweather/gweather-weather.c:219
 #| msgid "Moderate drizzle"
@@ -342,7 +342,7 @@ msgstr "ਭਾਰੀ ਮੀਂਹ"
 #: ../libgweather/gweather-weather.c:220
 #| msgid "Rain showers"
 msgid "rain showers"
-msgstr "ਮੀਂਹ ਦੀਆਂ ਫੁਹਾਰਾਂ"
+msgstr "ਮੀਂਹ ਦਆਂ ਫੁਹਾਰਾਂ"
 
 #: ../libgweather/gweather-weather.c:220
 #| msgid "Freezing rain"
@@ -382,7 +382,7 @@ msgstr "ਉੱਡਦੀ ਬਰਫ਼ਬਾਰੀ"
 #: ../libgweather/gweather-weather.c:221
 #| msgid "Snow showers"
 msgid "snow showers"
-msgstr "ਬਰਫ਼ੀਲੀਆਂ ਵਾਛੜਾਂ"
+msgstr "ਬਰਫ਼ੀਲਆਂ ਵਾਛੜਾਂ"
 
 #: ../libgweather/gweather-weather.c:221
 #| msgid "Drifting snow"
@@ -460,7 +460,7 @@ msgstr "ਗੜ੍ਹਿਆਂ ਦਾ ਤੂਫ਼ਾਨ"
 #: ../libgweather/gweather-weather.c:225
 #| msgid "Hail showers"
 msgid "hail showers"
-msgstr "ਗੜ੍ਹਿਆਂ ਦੀ ਵਾਛੜ"
+msgstr "ਗੜ੍ਹਿਆਂ ਦ ਵਾਛੜ"
 
 #. SMALL_HAIL
 #: ../libgweather/gweather-weather.c:226
@@ -627,7 +627,7 @@ msgstr "ਝੱਖੜ"
 #: ../libgweather/gweather-weather.c:241
 #| msgid "Dust whirls"
 msgid "dust whirls"
-msgstr "ਘੱਟੇ ਦੇ ਵਾਵਰੋਲੇ"
+msgstr "ਘੱਟੇ ਦੇ ਵਾਵਰੋਲ"
 
 #: ../libgweather/gweather-weather.c:241
 #| msgid "Dust whirls in the vicinity"
@@ -741,7 +741,7 @@ msgstr "ਭਾਰੀ ਗੜੇਮਾਰ"
 #. ICE_CRYSTALS
 #: ../libgweather/gweather-weather.c:259
 msgid "Ice crystals"
-msgstr "ਬਰਫ ਰਵੇ"
+msgstr "ਬਰ ਰਵੇ"
 
 #. ICE_PELLETS
 #: ../libgweather/gweather-weather.c:260
@@ -784,7 +784,7 @@ msgstr "ਫੁਹਾਰ (ਗੜ੍ਹੇ)"
 #. SMALL_HAIL
 #: ../libgweather/gweather-weather.c:262
 msgid "Small hail"
-msgstr "ਛੋਟੇ ਗੜ੍ਹੇ"
+msgstr "ਛਟੇ ਗੜ੍ਹੇ"
 
 #: ../libgweather/gweather-weather.c:262
 msgid "Small hailstorm"
@@ -1155,7 +1155,7 @@ msgstr ""
 #.
 #: ../libgweather/weather-yrno.c:507
 #| msgid ""
-#| "Weather data from the <a href=\"http://yr.no/\";>Norwegian Meteorological "
+#| "Weather data from the <a href=\"https://www.met.no/\";>Norwegian Meteorological "
 #| "Institute</a>"
 msgid ""
 "Weather data from the <a href=\"http://www.met.no/\";>Norwegian "
@@ -1258,7 +1258,7 @@ msgid ""
 "calculations, not for weather forecast."
 msgstr ""
 "ਮੌਸਮ ਟਿਕਾਣਾ ਲਈ ਮੂਲ ਟਿਕਾਣਾ ਹੈ। ਪਹਿਲਾਂ ਖੇਤਰ ਨਾਂ ਹੈ, ਜੋ ਕਿ ਵੇਖਾਇਆ ਜਾਵੇਗਾ। ਜੇ ਖਾਲੀ ਹੈ ਤਾਂ ਇਸ "
-"ਨੂੰ ਟਿਕਾਣਾ ਡਾਟਾਬੇਸ ਵਿੱਚੋਂ ਲਿਆ ਜਾਵੇਗਾ। ਦੂਜਾ ਖੇਤਰ ਹੈ ਮੂਲ ਮੌਸਮ ਵਿਭਾਗ ਦਾ METAR ਕੋਡ ਹੈ। ਇਹ ਖਾਲੀ "
+"ਨੂੰ ਟਿਕਾਣਾ ਡਾਟਾਬੇਸ ਵੱਚੋਂ ਲਿਆ ਜਾਵੇਗਾ। ਦੂਜਾ ਖੇਤਰ ਹੈ ਮੂਲ ਮੌਸਮ ਵਿਭਾਗ ਦਾ METAR ਕੋਡ ਹੈ। ਇਹ ਖਾਲੀ "
 "ਨਹੀਂ ਹੋਣਾ ਚਾਹੀਦਾ ਹੈ ਅਤੇ Locations.xml ਫਾਇਲ ਵਿੱਚੋਂ &lt;code&gt; ਟੈਗ ਦੇ ਨਾਲ ਸਬੰਧਿਤ ਹੋਣਾ "
 "ਚਾਹੀਦਾ ਹੈ। ਤੀਜਾ ਖੇਤਰ ਹੈ (ਲੰਬਕਾਰੀ, ਵਿਥਕਾਰੀ) ਦਾ ਦੂਹਰਾ ਮੁੱਲ (ਟੱਪਲ), ਜੋ ਕਿ ਡਾਟਾਬੇਸ ਮੁੱਲ ਨੂੰ "
 "ਅਣਡਿੱਠਾ ਕਰੇ। ਇਹ ਕੇਵਲ ਸੂਰਜ-ਚੜ੍ਹਨ ਅਤੇ ਚੰਦ ਕਲਾਵਾਂ ਕੱਢਣ ਲਈ ਹੀ ਵਰਤਿਆ ਜਾਂਦਾ ਹੈ ਨਾ ਕਿ ਮੌਸਮ ਦੀ "
diff --git a/po/sl.po b/po/sl.po
index bb30d430..df5ccdee 100644
--- a/po/sl.po
+++ b/po/sl.po
@@ -1206,10 +1206,10 @@ msgstr ""
 #~ msgstr "%d K"
 
 #~ msgid ""
-#~ "Weather data from the <a href=\"http://yr.no/\";>Norwegian Meteorological "
+#~ "Weather data from the <a href=\"https://www.met.no/\";>Norwegian Meteorological "
 #~ "Institute</a>"
 #~ msgstr ""
-#~ "Vremenski podatki <a href=\"http://yr.no/\";>Norveškega meteorološkega "
+#~ "Vremenski podatki <a href=\"https://www.met.no/\";>Norveškega meteorološkega "
 #~ "inštituta</a>"
 
 #~ msgid "Ice pellets"
diff --git a/po/ta.po b/po/ta.po
index e9ca5ac3..6f483e11 100644
--- a/po/ta.po
+++ b/po/ta.po
@@ -62,7 +62,7 @@ msgstr "மாறி"
 
 #: ../libgweather/weather.c:115
 msgid "North"
-msgstr "வடக்கு"
+msgstr "வடக்க"
 
 #: ../libgweather/weather.c:115
 msgid "North - NorthEast"
@@ -102,7 +102,7 @@ msgstr "தெற்கு - தென்மேற்கு"
 
 #: ../libgweather/weather.c:117
 msgid "Southwest"
-msgstr "தென்மேற்கு"
+msgstr "தென்மேறகு"
 
 #: ../libgweather/weather.c:117
 msgid "West - Southwest"
@@ -143,7 +143,7 @@ msgstr "சிதறலான மேகங்கள்"
 
 #: ../libgweather/weather.c:134
 msgid "Few clouds"
-msgstr "குறைவான மேகங்கள்"
+msgstr "கறைவான மேகங்கள்"
 
 #: ../libgweather/weather.c:135
 msgid "Overcast"
@@ -227,7 +227,7 @@ msgstr "மிகுந்த பனி"
 
 #: ../libgweather/weather.c:177
 msgid "Snowstorm"
-msgstr "பனிக்காற்று"
+msgstr "பனிக்காறறு"
 
 #: ../libgweather/weather.c:177
 msgid "Blowing snowfall"
@@ -337,7 +337,7 @@ msgstr "உறைபனி"
 
 #: ../libgweather/weather.c:185
 msgid "Fog in the vicinity"
-msgstr "அருகாமையில் உறைபனி"
+msgstr "அருகாமையில் றைபனி"
 
 #: ../libgweather/weather.c:185
 msgid "Shallow fog"
@@ -658,7 +658,7 @@ msgstr "METAR தரவை பெற முடியவில்லை: %d %s.\n
 
 #: ../libgweather/weather-owm.c:385
 #| msgid ""
-#| "Weather data from the <a href=\"http://yr.no/\";>Norwegian Meteorological "
+#| "Weather data from the <a href=\"https://www.met.no/\";>Norwegian Meteorological "
 #| "Institute</a>"
 msgid ""
 "Weather data from the <a href=\"http://openweathermap.org\";>Open Weather Map "
@@ -675,10 +675,10 @@ msgstr ""
 #.
 #: ../libgweather/weather-yrno.c:484
 msgid ""
-"Weather data from the <a href=\"http://yr.no/\";>Norwegian Meteorological "
+"Weather data from the <a href=\"https://www.met.no/\";>Norwegian Meteorological "
 "Institute</a>"
 msgstr ""
-"<a href=\"http://yr.no/\";>Norwegian Meteorological Institute</a>-லிருந்து "
+"<a href=\"https://www.met.no/\";>Norwegian Meteorological Institute</a>-லிருந்து "
 "காலநிலைத் தகவல்"
 
 #: ../schemas/org.gnome.GWeather.gschema.xml.h:1
@@ -727,7 +727,7 @@ msgid ""
 "'mph' (miles per hour), 'knots' and 'bft' (Beaufort scale)."
 msgstr ""
 "வானிலையை காட்ட வேகத்தின் அலகு. (உதாரணமாக  காற்றின் வேகம்). செல்லுபடியாகும் மதிப்புகள் "
-"'வினாடிக்கு மீட்டர்கள்', 'மணிக்கு கிமீ' 'மணிக்கு மைல்கள்', நாட்கள் மற்றும் பிஎஃப்டி "
+"'வினாடிக்கு மீட்டர்கள்', 'மணி்கு கிமீ' 'மணிக்கு மைல்கள்', நாட்கள் மற்றும் பிஎஃப்டி "
 "(ப்யூபோர்ட் அலகு)"
 
 #: ../schemas/org.gnome.GWeather.gschema.xml.h:9
@@ -742,7 +742,7 @@ msgid ""
 "mercury), 'inch-hg' (inches of mercury), 'atm' (atmospheres)."
 msgstr ""
 "வானிலையை காட்ட அழுத்தத்தின் அலகு.  செல்லுபடியாகும் மதிப்புகள் 'kpa'(க்லோபாஸ்கல்), "
-"'hpa' (ஹெக்டோபாஸ்கல்) 'mb' (மில்லிபார் கணிதத்தில் 1 hPa ஆனால் வேறூ விதமாக "
+"'hpa' (ஹெக்டோபாஸ்கல்) 'mb' (மில்லிபார் கணிதத்தில் 1 hPa ஆனால் வேறூ வதமாக "
 "காட்டப்படுகிறது), 'mm-hg' (மி.மீ பாதரசம்), 'inch-hg' (இன்ச் பாதரசம்), "
 "'atm' (அட்மாஸ்பியர்)."
 
@@ -760,9 +760,9 @@ msgid ""
 "value taken from the database. This is only used for sunrise and moon phase "
 "calculations, not for weather forecast."
 msgstr ""
-"வானிலை குறுநிரலுக்கு முன்னிருப்பு இடம். முதல் புலத்தில் பெயர். காலியாக இருந்தால் அது "
+"வானிலை குறுநிரலுக்கு முன்னிருப்ப இடம். முதல் புலத்தில் பெயர். காலியாக இருந்தால் அது "
 "இடங்கள் தரவுத்தளத்தில் இருந்து எடுக்கப்படும். இரண்டாம் புலம் முன்னிருப்பு வானிலை "
 "நிலையத்துக்கான மெடார் குறீயீடு. இது காலியாக இருக்கக்கூடாது. Locations.xml  கோப்பில் "
 "உள்ள &lt;code&gt; ஒட்டுடன் இது ஒத்து போக வேண்டும். மூன்றாம் புலம் ஒரு ட்யூபில். "
 "அட்சரேகை, தீர்கரேகை. இது தரவுத்தளத்தில் இருந்து எடுத்த மதிப்பை மேலாளும். இது பயனாவது "
-"சூரிய உதயம், சந்திர கலை கணக்குகளுக்கு, வானிலைக்கு அல்ல."
+"சூரிய உதம், சந்திர கலை கணக்குகளுக்கு, வானிலைக்கு அல்ல."
diff --git a/po/te.po b/po/te.po
index 82cb18f2..ae34bf79 100644
--- a/po/te.po
+++ b/po/te.po
@@ -654,7 +654,7 @@ msgstr "METAR ‍డాటా పొందుటలో విఫలమైంద
 
 #: ../libgweather/weather-owm.c:385
 #| msgid ""
-#| "Weather data from the <a href=\"http://yr.no/\";>Norwegian Meteorological "
+#| "Weather data from the <a href=\"https://www.met.no/\";>Norwegian Meteorological "
 #| "Institute</a>"
 msgid ""
 "Weather data from the <a href=\"http://openweathermap.org\";>Open Weather Map "
@@ -671,10 +671,10 @@ msgstr ""
 #.
 #: ../libgweather/weather-yrno.c:484
 msgid ""
-"Weather data from the <a href=\"http://yr.no/\";>Norwegian Meteorological "
+"Weather data from the <a href=\"https://www.met.no/\";>Norwegian Meteorological "
 "Institute</a>"
 msgstr ""
-"<a href=\"http://yr.no/\";>నార్వేజియన్ మెట్రోలాజికల్ యిన్‌స్టిట్యూట్</a> నుండి "
+"<a href=\"https://www.met.no/\";>నార్వేజియన్ మెట్రోలాజికల్ యిన్‌స్టిట్యూట్</a> నుండి "
 "వాతావరణ దత్తాంశం"
 
 #: ../schemas/org.gnome.GWeather.gschema.xml.h:1
@@ -698,7 +698,7 @@ msgid ""
 "The unit of temperature used for showing weather. Valid values are 'kelvin', "
 "'centigrade' and 'fahrenheit'."
 msgstr ""
-"ఉష్ణోగ్రత యొక్క యూనిట్ వాతావరణ చూపడం కోసం ఉపయోగిస్తారు. చెల్లుబాటు అయ్యే "
+"ష్ణోగ్రత యొక్క యూనిట్ వాతావరణ చూపడం కోసం ఉపయోగిస్తారు. చెల్లుబాటు అయ్యే "
 "విలువలు 'కెల్విన్', 'సెల్సియస్ "
 "కొలమానము' మరియు 'ఫారెన్హీట్' ఉన్నాయి."
 
@@ -714,7 +714,7 @@ msgid ""
 msgstr ""
 "దూరం యొక్క యూనిట్ వాతావరణానికి కూడా ఉపయోగిస్తారు (ప్రత్యక్షత కోసం ఉదాహరణకు "
 "లేదా ముఖ్యమైన సంఘటనల యొక్క "
-"దూరం కోసం) . చెల్లుబాటు అయ్యే విలువలు 'మీటర్లు', 'కిమీ' మరియు 'మైళ్ళు' "
+"దరం కోసం) . చెల్లుబాటు అయ్యే విలువలు 'మీటర్లు', 'కిమీ' మరియు 'మైళ్ళు' "
 "ఉన్నాయి."
 
 #: ../schemas/org.gnome.GWeather.gschema.xml.h:7
@@ -729,7 +729,7 @@ msgid ""
 msgstr ""
 "వేగం యొక్క యూనిట్ వాతావరణాన్ని (గాలి వేగం కోసం ఉదాహరణకు) చూపించడానికి  "
 "ఉపయోగిస్తారు. చెల్లుబాటు అయ్యే "
-"విలువలు 'ms' (సెకనుకు మీటర్లు), 'kph' (గంటకు కిలోమీటర్లు), 'mph' (గంటకు "
+"విలువలు 'ms' (సెకనుకు మీటర్లు), 'kph' (గంటకు కిలోమీటర్లు), 'mph' (గంటు "
 "మైళ్ళు), "
 "'చిక్కులు' మరియు 'bft' (బ్యూఫోర్ట్ ఎత్తున) ఉన్నాయి."
 
@@ -748,7 +748,7 @@ msgstr ""
 "'KPA' (kilopascal), "
 "'hPa' (hectopascal), 'mb' (millibar, 1 hPa అనేది గణితశాస్త్ర సమానమైన కాని "
 "విభిన్నంగా "
-"చూపిన), 'mm-HG' (పాదరసం యొక్క millimeters), 'అంగుళాల-HG' (ఉన్నాయి పాదరసం "
+"చపిన), 'mm-HG' (పాదరసం యొక్క millimeters), 'అంగుళాల-HG' (ఉన్నాయి పాదరసం "
 "యొక్క "
 "అంగుళాలు), 'ATM' (వాతావరణం)."
 
@@ -766,7 +766,7 @@ msgid ""
 "value taken from the database. This is only used for sunrise and moon phase "
 "calculations, not for weather forecast."
 msgstr ""
-"వాతావరణ ఆప్లెట్ కోసం డిఫాల్ట్ స్థానాన్ని. మొదటి ఫీల్డ్ చూపబడుతుంది ఆ పేరు. "
+"వాతావరణ ఆప్లెట్ కోసం డిఫాల్ట్ సథానాన్ని. మొదటి ఫీల్డ్ చూపబడుతుంది ఆ పేరు. "
 "ఖాళీ ఉంటే, అది స్థానాలను డేటాబేస్ "
 "నుంచి తీసుకెళ్ళబడతారు. రెండవ field అప్రమేయ వాతావరణ కేంద్రం కోసం METAR కోడ్ "
 "ఉంది. ఇది ఖాళీ "
@@ -884,7 +884,7 @@ msgstr ""
 #~ msgstr "m"
 
 #~ msgid "km"
-#~ msgstr "కిలోమీటరు"
+#~ msgstr "ిలోమీటరు"
 
 #~ msgid "mi"
 #~ msgstr "mi"
@@ -931,7 +931,7 @@ msgstr ""
 #~ msgstr "రాడార్ పటామును ప్రదర్శించుము"
 
 #~ msgid "Fetch a radar map on each update."
-#~ msgstr "ప్రతి తాజాదనమునకు ఒక రాడార్ పటమును తెమ్ము."
+#~ msgstr "ప్రతి తాజాదనమునకు ఒక రాడర్ పటమును తెమ్ము."
 
 #~ msgid ""
 #~ "If true, then retrieve a radar map from a location specified by the "
@@ -994,7 +994,7 @@ msgstr ""
 #~ msgstr "మెట్రిక్ ప్రమాణములను ఉపయోగించుము"
 
 #~ msgid "Use metric units instead of english units."
-#~ msgstr "ఆంగ్ల ప్రమాణములకు బదులుగా మెట్రిక్ ప్రమాణములను ఉపయోగించుము."
+#~ msgstr "ఆగ్ల ప్రమాణములకు బదులుగా మెట్రిక్ ప్రమాణములను ఉపయోగించుము."
 
 #~ msgid "Weather for a city"
 #~ msgstr "పట్టణము వాతావరణము"
diff --git a/po/ug.po b/po/ug.po
index c12bcaf5..d509faac 100644
--- a/po/ug.po
+++ b/po/ug.po
@@ -26,7 +26,7 @@ msgstr "گىرىنۋىچ ۋاقتى"
 #: ../libgweather/timezone-menu.c:278
 msgctxt "timezone"
 msgid "Unknown"
-msgstr "نامەلۇم"
+msgstr "نامەلم"
 
 #: ../libgweather/weather.c:129
 msgid "Variable"
@@ -291,7 +291,7 @@ msgstr "ئۇششاق مۆلدۈر يامغۇرى"
 #. PRECIPITATION
 #: ../libgweather/weather.c:198
 msgid "Unknown precipitation"
-msgstr "نامەلۇم ئالدىن مەلۇمات"
+msgstr "ناەلۇم ئالدىن مەلۇمات"
 
 #. MIST
 #: ../libgweather/weather.c:199
@@ -654,10 +654,10 @@ msgstr "METAR سانلىق-مەلۇماتلىرىغا ئېرىشەلمىدى: %d
 #. 
 #: ../libgweather/weather-yrno.c:416
 msgid ""
-"Weather data from the <a href=\"http://yr.no/\";>Norwegian Meteorological "
+"Weather data from the <a href=\"https://www.met.no/\";>Norwegian Meteorological "
 "Institute</a>"
 msgstr ""
-"<a href=\"http://yr.no/\";>نورۋېگىيە ھاۋارايى ئىنستىتۇتى</a>دىن ئېلىنغان "
+"<a href=\"https://www.met.no/\";>نورۋېگىيە ھاۋارايى ئىنستىتۇتى</a>دىن ئېلىنغان "
 "سانلىق-مەلۇماتلار"
 
 #: ../schemas/org.gnome.GWeather.gschema.xml.h:1
@@ -726,7 +726,7 @@ msgid ""
 "'mph' (miles per hour), 'knots' and 'bft' (Beaufort scale)."
 msgstr ""
 "ھاۋارايىدا تېزلىكنى بىلدۈرىدىغان بىرلىك(يەنى شامالنىڭ تېزلىكى دېگەندەك). "
-"ئىناۋەتلىك قىممەتلەر 'ms' (ھەر سېكۇنتتىكى مېتىر)، 'kph' (ھەر سائەتتىكى "
+"ئىناۋەتلىك قىممەتلەر 'ms' (ھەر سېكۇنتتىكى مېتىر)، 'kph' (ھە سائەتتىكى "
 "كىلومېتىر)، 'mph' (ھەر سائەتتىكى مايل), 'knots' ۋە 'bft' (Beaufort scale)."
 
 #. TRANSLATORS: pick a default pressure unit for your locale, see key description
diff --git a/po/vi.po b/po/vi.po
index 34b55a66..2d2f9648 100644
--- a/po/vi.po
+++ b/po/vi.po
@@ -23,7 +23,7 @@ msgstr ""
 
 #: ../libgweather/gweather-timezone.c:316
 msgid "Greenwich Mean Time"
-msgstr "Múi giờ Greenwich"
+msgstr "Múi gi Greenwich"
 
 #: ../libgweather/timezone-menu.c:278
 msgctxt "timezone"
@@ -278,7 +278,7 @@ msgstr "Mưa đá thất thường"
 #. SMALL_HAIL
 #: ../libgweather/weather.c:197
 msgid "Small hail"
-msgstr "Mưa đá-nhỏ"
+msgstr "Mưa đá-nh"
 
 #: ../libgweather/weather.c:197
 msgid "Small hailstorm"
@@ -644,10 +644,10 @@ msgstr "Lỗi lấy dữ liệu METAR: %d %s.\n"
 #.
 #: ../libgweather/weather-yrno.c:416
 msgid ""
-"Weather data from the <a href=\"http://yr.no/\";>Norwegian Meteorological "
+"Weather data from the <a href=\"https://www.met.no/\";>Norwegian Meteorological "
 "Institute</a>"
 msgstr ""
-"Dữ liệu thời tiết từ <a href=\"http://yr.no/\";>Viện Thời tiết Na Uy</a>"
+"Dữ liệu thời tiết từ <a href=\"https://www.met.no/\";>Viện Thời tiết Na Uy</a>"
 
 #: ../schemas/org.gnome.GWeather.gschema.xml.h:1
 msgid "URL for the radar map"
@@ -934,7 +934,7 @@ msgstr ""
 #~ msgstr "Tự động cập nhật dữ liệu"
 
 #~ msgid "Use custom url for the radar map"
-#~ msgstr "Dùng địa chỉ Mạng tự chọn cho bản đồ ra đa"
+#~ msgstr "Dùng đa chỉ Mạng tự chọn cho bản đồ ra đa"
 
 #~ msgid "Use metric units"
 #~ msgstr "Dùng đơn vị mét"


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/libgweather/gweather-weather.c b/libgweather/gweather-weather.c
index 8b8122c7..a57e2283 100644
--- a/libgweather/gweather-weather.c
+++ b/libgweather/gweather-weather.c
@@ -723,9 +723,9 @@ gweather_info_update (GWeatherInfo *info)
     if (ok)
        return;
 
-    /* Try yr.no next */
-    if (priv->providers & GWEATHER_PROVIDER_YR_NO)
-       ok = yrno_start_open (info);
+    /* Try met.no next */
+    if (priv->providers & GWEATHER_PROVIDER_MET_NO)
+       ok = metno_start_open (info);
     if (ok)
        return;
 
diff --git a/libgweather/gweather-weather.h b/libgweather/gweather-weather.h
index 1a800d06..2c34a4a2 100644
--- a/libgweather/gweather-weather.h
+++ b/libgweather/gweather-weather.h
@@ -35,7 +35,7 @@ G_BEGIN_DECLS
  * @GWEATHER_PROVIDER_METAR: METAR office, providing current conditions worldwide
  * @GWEATHER_PROVIDER_IWIN: US weather office, providing 7 days of forecast
  * @GWEATHER_PROVIDER_YAHOO: Yahoo Weather Service, removed in 3.27.1
  * @GWEATHER_PROVIDER_YR_NO: Yr.no service, worldwide but requires attribution
  * @GWEATHER_PROVIDER_OWM: OpenWeatherMap, worldwide and possibly more reliable, but requires attribution 
and is limited in the number of queries
  * @GWEATHER_PROVIDER_ALL: enable all available providers
  */
@@ -44,7 +44,7 @@ typedef enum { /*< flags, underscore_name=gweather_provider >*/
     GWEATHER_PROVIDER_METAR = 1,
     GWEATHER_PROVIDER_IWIN = 1 << 2,
     GWEATHER_PROVIDER_YAHOO = 1 << 3,
-    GWEATHER_PROVIDER_YR_NO = 1 << 4,
+    GWEATHER_PROVIDER_MET_NO = 1 << 4,
     GWEATHER_PROVIDER_OWM = 1 << 5,
     GWEATHER_PROVIDER_ALL = 31
 } GWeatherProvider;
@@ -35,7 +35,7 @@ G_BEGIN_DECLS
  * @GWEATHER_PROVIDER_IWIN: US weather office, providing 7 days of forecast
  * @GWEATHER_PROVIDER_YAHOO: Yahoo Weather Service, removed in 3.27.1
- * @GWEATHER_PROVIDER_YR_NO: Yr.no service, worldwide but requires attribution
+ * @GWEATHER_PROVIDER_MET_NO: MET.no service, worldwide but requires attribution
  * @GWEATHER_PROVIDER_OWM: OpenWeatherMap, worldwide and possibly more reliable, but requires attribution 
and is limited in the number of queries
diff --git a/libgweather/weather-yrno.c b/libgweather/weather-metno.c
similarity index 95%
rename from libgweather/weather-yrno.c
rename to libgweather/weather-metno.c
index b9e2e3e2..72ee1827 100644
--- a/libgweather/weather-yrno.c
+++ b/libgweather/weather-metno.c
@@ -1,5 +1,5 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
 /* weather-yrno.c - MET Norway Weather service.
  *
  * Copyright 2012 Giovanni Campagna <scampa giovanni gmail com>
  *
@@ -42,9 +42,9 @@ typedef struct {
     int code;
     GWeatherSky sky;
     GWeatherConditions condition;
-} YrnoSymbol;
+} MetnoSymbol;
 
-static YrnoSymbol symbols[] = {
+static MetnoSymbol symbols[] = {
     { 1,  GWEATHER_SKY_CLEAR,     { FALSE, GWEATHER_PHENOMENON_NONE, GWEATHER_QUALIFIER_NONE } }, /* Sun */
     { 2,  GWEATHER_SKY_BROKEN,    { FALSE, GWEATHER_PHENOMENON_NONE, GWEATHER_QUALIFIER_NONE } }, /* 
LightCloud */
     { 3,  GWEATHER_SKY_SCATTERED, { FALSE, GWEATHER_PHENOMENON_NONE, GWEATHER_QUALIFIER_NONE } }, /* 
PartlyCloudy */
@@ -145,7 +145,7 @@ date_to_time_t (const xmlChar *str, const char * tzid)
     return rval;
 }
 
-static YrnoSymbol *
+static MetnoSymbol *
 symbol_search (int code)
 {
     int a = 0;
@@ -153,7 +153,7 @@ symbol_search (int code)
 
     while (a < b) {
        int c = (a + b)/2;
-       YrnoSymbol *yc = symbols + c;
+       MetnoSymbol *yc = symbols + c;
 
        if (yc->code == code)
            return yc;
@@ -171,7 +171,7 @@ read_symbol (GWeatherInfo *info,
             xmlNodePtr    node)
 {
     xmlChar *val;
-    YrnoSymbol* symbol;
+    MetnoSymbol* symbol;
     GWeatherInfoPrivate *priv = info->priv;
 
     val = xmlGetProp (node, XC("number"));
@@ -391,7 +391,7 @@ parse_forecast_xml_new (GWeatherInfo    *master_info,
 }
 
 static void
-yrno_finish_new (SoupSession *session,
+metno_finish_new (SoupSession *session,
                 SoupMessage *msg,
                 gpointer     user_data)
 {
@@ -403,11 +403,11 @@ yrno_finish_new (SoupSession *session,
     if (!SOUP_STATUS_IS_SUCCESSFUL (msg->status_code)) {
        /* forecast data is not really interesting anyway ;) */
        if (msg->status_code == SOUP_STATUS_CANCELLED) {
-           g_debug ("Failed to get Yr.no forecast data: %d %s\n",
+           g_debug ("Failed to get met.no forecast data: %d %s\n",
                     msg->status_code, msg->reason_phrase);
            return;
        }
-       g_message ("Failed to get Yr.no forecast data: %d %s\n",
+       g_message ("Failed to get met.no forecast data: %d %s\n",
                   msg->status_code, msg->reason_phrase);
        _gweather_info_request_done (user_data, msg);
        return;
@@ -416,12 +416,12 @@ yrno_finish_new (SoupSession *session,
     info = user_data;
     priv = info->priv;
     loc = &priv->location;
-    g_debug ("yrno data for %lf, %lf", loc->latitude, loc->longitude);
+    g_debug ("metno data for %lf, %lf", loc->latitude, loc->longitude);
     g_debug ("%s", msg->response_body->data);
 
     parse_forecast_xml_new (info, msg->response_body);
     num_forecasts = g_slist_length (priv->forecast_list);
-    g_debug ("yrno parsed %d forecast infos", num_forecasts);
+    g_debug ("metno parsed %d forecast infos", num_forecasts);
     if (!priv->valid)
         priv->valid = (num_forecasts > 0);
 
@@ -429,7 +429,7 @@ yrno_finish_new (SoupSession *session,
 }
 
 gboolean
-yrno_start_open (GWeatherInfo *info)
+metno_start_open (GWeatherInfo *info)
 {
     GWeatherInfoPrivate *priv;
     gchar *url;
@@ -449,11 +449,11 @@ yrno_start_open (GWeatherInfo *info)
     g_ascii_dtostr (lonstr, sizeof(lonstr), RADIANS_TO_DEGREES (loc->longitude));
 
     url = g_strdup_printf("https://api.met.no/weatherapi/locationforecast/1.9/?lat=%s;lon=%s";, latstr, 
lonstr);
-    g_debug ("yrno_start_open, requesting: %s", url);
+    g_debug ("metno_start_open, requesting: %s", url);
 
     message = soup_message_new ("GET", url);
     _gweather_info_begin_request (info, message);
-    soup_session_queue_message (priv->session, message, yrno_finish_new, info);
+    soup_session_queue_message (priv->session, message, metno_finish_new, info);
 
     g_free (url);
 
@@ -1,5 +1,5 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-/* weather-yrno.c - MET Norway Weather service.
+/* weather-metno.c - MET Norway Weather service.
  *
  * Copyright 2012 Giovanni Campagna <scampa giovanni gmail com>